import grapesjs from 'grapesjs';
import pluginBlocks from 'grapesjs-blocks-basic';
import pluginNavbar from 'grapesjs-navbar';
import pluginCountdown from 'grapesjs-component-countdown';
import pluginForms from 'grapesjs-plugin-forms-ca';
import pluginExport from 'grapesjs-plugin-export';
import pluginAviary from 'grapesjs-aviary';
import pluginFilestack from 'grapesjs-plugin-filestack';

import commands from './commands';
import blocks from './blocks';
import components from './components';
import panels from './panels';
import styles from './styles';

const lang = {
    cc: "webpage",
    absolute: "absolutna",
    actions: "Akcje",
    activateCode: "Aktywuj kod rabat w tle",
    addImage: "Dodaj obrazek",
    alt: "Tekst zastepczy",
    background: "Tło",
    basic: "Podstawowe",
    block: "Blok",
    border: "Obramowanie",
    bottom: "Dół",
    boxShadow: "Cień",
    button: "Przycisk",
    cat1: "Szablony Pop-up",
    cat2: "Zapisane szablony",
    cat3: "Szablony Widget",
    cat4: "Szablony Email",
    cat5: "Szablony Web push",
    checkbox: "Checkbox",
    circle: "Okrąg",
    classes: "Klasy",
    click: "Kliknięcie",
    closeIcon: "Ikona zamknięcia",
    closePopup: "Zamknij pop-up",
    color: "Kolor",
    column: "Kolumna",
    columns: "Kolumny",
    componentSettings: "Ustawienia elementu",
    customCode: "Własny kod",
    customFont: "Własna czcionka",
    decorations: "Dekoracja",
    dimension: "Rozmiar",
    display: "Wyświelatnie",
    dropHere: "Upuści pliki tutaj lub kliknij",
    elements: "Elementy",
    extra: "Dodatkowe",
    fixed: "Pływanie",
    float: "Wyrównanie",
    fontFamily: "Czcionka",
    fontSize: "Rozmiar",
    fontWeight: "Grubość",
    form: "Formularz",
    forms: "Formularze",
    general: "Ogólne",
    groupOfProducts: "Grupa produktów",
    height: "Wysokość",
    hover: "Najechanie",
    image: "Obrazek",
    inline: "Linnia",
    inlineB: "Pełna Linnia",
    input: "Pole",
    label: "Tytuł",
    layers: "Warstwy",
    layout: "Układ",
    left: "Lewa",
    letterSpacing: "Odstęp",
    lineHeight: "Wysokość linni",
    link: "Link",
    location: "Lokacja",
    margin: "Margines",
    move: "Przenieś do koszyka i atywuj rabat",
    name: "Nazwa",
    none: "brak",
    padding: "Padding",
    parity: "Parzysty",
    perspective: "Perspektywa",
    popupSettings: "Ustawienia Pop-up",
    popupSettingsTitle: "Ustaw pozycję pop-up",
    position: "Pozycja",
    price: "Cena",
    quantity: "Ilość",
    radio: "Radio",
    radius: "zaokrąglenie",
    rectangle: "Prostokąt",
    relative: "relatywnie",
    required: "Wymagane",
    right: "Prawo",
    rotate: "obrót",
    select: "Wybierz",
    selected: "Wybrane",
    selectElement: "Wybierz element przed edycją",
    selectImage: "Wybierz obrazek",
    settings: "Ustawienia",
    shapes: "Figury",
    showCode: "Pokaż kod rabatowy",
    square: "Kwadrat",
    state: "- Stan -",
    static: "statyczne",
    style: "styl",
    templates: "Szablony",
    text: "Tekst",
    textAlign: "Pozycja tekstu",
    textArea: "Obszar tekstowy",
    textShadow: "Cień tekstu",
    top: "Góra",
    transform: "Przesunięcie",
    transition: "Przejście",
    typography: "Typografia",
    width: "Szerokość",
    "max-width": "Szerkość max",
    "min-height": "Wysokość max",
    "margin-top": "Góra",
    "margin-left": "Lewa",
    "margin-right": "Prawa",
    "margin-bottom": "Dół",
    "padding-top": "Góra",
    "padding-left": "Lewa",
    "padding-right": "Prawa",
    "padding-bottom": "Dół",
    "font-family": "Czcionka",
    "font-size": "Rozmiar",
    "font-weight": "Grubość",
    "letter-spacing": "Odstęp",
    "line-height": "Wyskość linni",
    "text-align": "Wyrówanie",
    "text-shadow": "Cień",
    "text-shadow-h": "Pozycja X",
    "text-shadow-v": "Pozycja Y",
    "text-shadow-blur": "Zasięg",
    "text-shadow-color": "Kolor",
    "transform-rotate-x": "Rotacja X",
    "transform-rotate-y": "Rotacja Y",
    "transform-rotate-z": "Rotacja Z",
    "transform-scale-x": "Skalowanie X",
    "transform-scale-y": "Skalowanie Y",
    "transform-scale-z": "Skalowanie Z",
    "background-image": "Obrazek",
    "background-repeat": "Powtarzanie",
    "background-position": "Pozycja",
    "background-attachment": "Załącznik",
    "background-size": "Rozmiar",
    "background-color": "Kolor",
    "transition-property": "Animuj",
    "transition-duration": "Czas",
    "transition-timing-function": "Animacja",
    "border-radius": "Zaokrąglenie",
    "border-top-left-radius": "Lewa góra",
    "border-top-right-radius": "Prawa góra",
    "border-bottom-left-radius": "Lewy dół",
    "border-bottom-right-radius": "Prawy dół",
    "border-width": "Grubość",
    "border-style": "Styl",
    "border-color": "Kolor",
    "box-shadow": "Cień",
    prop: {
        none: "brak",
        left: "lewa",
        right: "prawa",
        block: "blok",
        inline: "w linni",
        static: "statyczna",
        relative: "relatywna",
        absolute: "absolutna",
        fixed: "pływająca",
        "inline-block": "w bloku",
    }

};
if(!window.lang) {
    window.lang = lang;
}

export default grapesjs.plugins.add('gjs-preset-webpage', (editor, opts = {}) => {
  let config = opts;

  let defaults = {
    // Which blocks to add
    blocks: ['link-block', 'quote', 'text-basic'],

    // Modal import title
    modalImportTitle: 'Import',

    // Modal import button text
    modalImportButton: 'Import',

    // Import description inside import modal
    modalImportLabel: '',

    // Default content to setup on import model open.
    // Could also be a function with a dynamic content return (must be a string)
    // eg. modalImportContent: editor => editor.getHtml(),
    modalImportContent: '',

    // Code viewer (eg. CodeMirror) options
    importViewerOptions: {},

    // Confirm text before cleaning the canvas
    textCleanCanvas: 'Are you sure to clean the canvas?',

    // Show the Style Manager on component change
    showStylesOnChange: 1,

    // Text for General sector in Style Manager
    textGeneral: window.lang['general'],

    // Text for Layout sector in Style Manager
    textLayout: window.lang['layout'],

    // Text for Typography sector in Style Manager
    textTypography: window.lang['typography'],

    // Text for Decorations sector in Style Manager
    textDecorations: window.lang['decorations'],

    // Text for Extra sector in Style Manager
    textExtra: window.lang['extra'],

    // Use custom set of sectors for the Style Manager
    customStyleManager: [],

    // `grapesjs-blocks-basic` plugin options
    // By setting this option to `false` will avoid loading the plugin
    blocksBasicOpts: {},

    // `grapesjs-navbar` plugin options
    // By setting this option to `false` will avoid loading the plugin
    navbarOpts: {},

    // `grapesjs-component-countdown` plugin options
    // By setting this option to `false` will avoid loading the plugin
    countdownOpts: {},

    // `grapesjs-plugin-forms` plugin options
    // By setting this option to `false` will avoid loading the plugin
    formsOpts: {},

    // `grapesjs-plugin-export` plugin options
    // By setting this option to `false` will avoid loading the plugin
    exportOpts: {},

    // `grapesjs-aviary` plugin options, disabled by default
    // Aviary library should be included manually
    // By setting this option to `false` will avoid loading the plugin
    aviaryOpts: 0,

    // `grapesjs-plugin-filestack` plugin options, disabled by default
    // Filestack library should be included manually
    // By setting this option to `false` will avoid loading the plugin
    filestackOpts: 0,
  };

  // Load defaults
  for (let name in defaults) {
    if (!(name in config))
      config[name] = defaults[name];
  }

  const {
    blocksBasicOpts,
    navbarOpts,
    countdownOpts,
    formsOpts,
    exportOpts,
    aviaryOpts,
    filestackOpts
  } = config;

  // Load plugins
  blocksBasicOpts && pluginBlocks(editor, blocksBasicOpts);
  navbarOpts && pluginNavbar(editor, navbarOpts);
  countdownOpts && pluginCountdown(editor, countdownOpts);
  formsOpts && pluginForms(editor, formsOpts);
  exportOpts && pluginExport(editor, exportOpts);
  aviaryOpts && pluginAviary(editor, aviaryOpts);
  filestackOpts && pluginFilestack(editor, filestackOpts);

  // Load components
  components(editor, config);

  // Load blocks
  blocks(editor, config);

  // Load commands
  commands(editor, config);

  // Load panels
  panels(editor, config);

  // Load styles
  styles(editor, config);

});
